# Shimarin

Asynchronous event-based communication between client and server.


# How to use

Examples are in the example folder

# Install

```
pip install Shimarin
```
<p align="center">
<img src="https://count.kamuridesu.com?username=shimarin" alt="count"/>
</p>